..
  SPDX-FileCopyrightText: 2016-2019 The Atlite Authors

  SPDX-License-Identifier: CC-BY-4.0

#############
More Examples
#############

All examples are available as Jupyter notebooks in our 
`Atlite GitHub repository <https://github.com/pypsa/atlite/docs/examples>`_.


If you are missing an example for a certain
aspect of atlite or if you have created some
examples of your own we would be happy to hear
from you.
Feel free to open a 
`Pull Request <https://github.com/PyPSA/atlite/pulls>`_
or an
`Issue <https://github.com/PyPSA/atlite/issues>`_
for your suggestion.

